@@ -13,6 +13,7 @@ class CurrentTaskInfo(Vertical):
             border: solid $primary;
             background: $background;
             height: 1fr;
+            padding: 1;
         }
     """
 
@@ -22,7 +23,7 @@ class CurrentTaskInfo(Vertical):
         self.border_title = "Задача"
 
     def compose(self) -> ComposeResult:
-        yield Static(id="task_text")
+        yield Static(id="task_text", markup=False)
 
     def watch_state(self, new_state: AppState) -> None:
         selected_task_id = new_state.current.task_id
